FrameStreamConfig

Struct FrameStreamConfig 

#[repr(C)]
pub struct FrameStreamConfig { pub stream_conf: StreamConfig, pub frame_hz: u32, pub enable_optimisations: bool, pub enable_draw_reorder: bool, pub interpolation_conf: InterpolationConfig, }
A set of stream configuration parameters unique to Frame streams.

Fields

stream_conf: StreamConfigframe_hz: u32

The rate at which the stream will attempt to present images via the DAC. This value is used in combination with the DAC’s point_hz in order to determine how many points should be used to draw each frame. E.g.

let points_per_frame = point_hz / frame_hz;

This is simply used as a minimum value. E.g. if some very simple geometry is submitted, this allows the DAC to spend more time creating the path for the image. However, if complex geometry is submitted that would require more than the ideal points_per_frame, the DAC may not be able to achieve the desired frame_hz when drawing the path while also taking the distance_per_point and radians_per_point into consideration.

enable_optimisations: bool

Enable or disable frame optimisations.

By default, optimisations are enabled. This includes path re-interpolation, as re-interpolation is only possible using a euler circuit which is created during the optimisation pass.

Read more about the kinds of optimisations applied at the lasy API documentation.

Returns true on success or false if the communication channel was closed.

enable_draw_reorder: bool

Enable or disable draw path reordering.

When true, the optimisation pass will attempt to find a more optimal path for the drawing of each line segment before performing interpolation. This is achieved by constructing a euler graph with the minimum number of blanks required to complete the path, and then finding a euler circuit through the path that minimises the number of sharp angles.

When false, the draw order will follow the order in which segments were submitted via the Frame.

By default, this value is true.

interpolation_conf: InterpolationConfig

Configuration options for eulerian circuit interpolation.